@@ -10,7 +10,7 @@
 #define PCI_HAVE_PM_DUMP
 #define PCI_COMPRESSED_IDS
 #define PCI_IDS "pci.ids.gz"
-#define PCI_PATH_IDS_DIR "/usr/share"
+#define PCI_PATH_IDS_DIR "/usr/share/hwdata"
 #define PCI_USE_DNS
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
-#define PCILIB_VERSION "3.1.7"
+#define PCILIB_VERSION "3.1.9"
